@@ -254,7 +254,12 @@ public class ItemToZenodoConverter {
 		zm.setConference_session_part(depositionMetadata.getConference_session_part());
 		zm.setConference_title(depositionMetadata.getConference_title());
 		zm.setConference_url(depositionMetadata.getConference_url());
+		
 		zm.setContributors(toZenodoContributors(depositionMetadata.getContributors()));
+		
+		//to manage empty or null contributors from mapping
+		zm.setContributorsTypes(CkanToZenodoUtil.toSerializableEnum(null, Contributor.Type.values()));
+		
 		zm.setCreators(toZenodoCreators(depositionMetadata.getCreators()));
 		zm.setDates(toZenodoDateIntervals(depositionMetadata.getDates()));
 		zm.setEmbargo_date(depositionMetadata.getEmbargo_date());
@@ -444,6 +449,13 @@ public class ItemToZenodoConverter {
 	 */
 	public static DepositionMetadata updateMetadataInfoOfDepositionMetadata(ZenodoMetadata metadata, DepositionMetadata depositionMetadata) {
 		
+		//description
+		String description = metadata.getDescription();
+		LOG.debug("Read description: "+description);
+		if(description!=null) {
+			depositionMetadata.setDescription(description);
+		}
+		
 		//upload type
 		SerializableEnum<String> uploadType = metadata.getUpload_type();
 		LOG.debug("Read upload type: "+uploadType);
